@@ -1,4 +1,5 @@
-// Copyright (C) 2003, 2009 Free Software Foundation, Inc.
+// Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009
+// Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -29,7 +30,7 @@ test01()
   char buf[2];
   VERIFY( std::cin.rdbuf()->sgetn(buf, 2) == 2 );
   int c1 = std::cin.rdbuf()->sungetc();
-  int c2 = std::fgetc(stdin);
+  int c2 = std::cin.rdbuf()->sbumpc();
   VERIFY( c1 == std::char_traits<char>::to_int_type(buf[1]) );
   VERIFY( c2 == c1 );
 }
